Learn R Programming

flintyR (version 0.1.0)

buildReverse: Map from Label Pairs to Indices

Description

Builds a map from pairs of labels to indexes. This is for caching distances, to avoid recomputing Hamming distances especially when dealing with high-dimensional (large \(P\)) matrices.

Usage

buildReverse(N)

Value

\(N \times N\) matrix whose entries record the index corresponding to the pair of labels (indexed by the matrix dims)

Arguments

N

Sample size, i.e., nrow(\(\mathbf{X}\))

Details

Dependencies: None