Learn R Programming

flintyR (version 0.1.0)

getCov: Covariance Computations Between Pairs of Distances (Independent Case)

Description

Computes covariance matrix entries and associated alpha, beta and gamma quantities defined in Aw, Spence and Song (2023), assuming the \(P\) features of the dataset \(\mathbf{X}\) are independent.

Usage

getCov(X, p = 2)

Value

The three distinct entries of covariance matrix, \((\alpha, \beta, \gamma)\)

Arguments

X

The binary or real matrix

p

The power \(p\) of \(l_p^p\), i.e., \(||x||_p^p = (x_1^p+...x_n^p)\)

Details

This is used in the large \(P\) asymptotics of the permutation test.

Dependencies: buildReverse, getLpDistance